.. _api-reference:

*************
API reference
*************

.. _api-reference-lc:

LMU Layers
==========

.. automodule:: keras_lmu.layers

    .. autoautosummary:: keras_lmu.layers
        :nosignatures:
